@@ -19,6 +19,7 @@
 #include <algorithm>
 #include <cstdio>
 #include <vector>
+
 #include "common.h"
 #include "rectangle.h"
 #include "bitmap.h"
@@ -33,21 +34,19 @@ void delete_hole( std::vector< Bitmap * > & holep_vector,
   {
   std::replace( v1.begin() + i, v1.end(), p, (Bitmap *) 0 );
   std::replace( v2.begin(), v2.begin() + i, p, (Bitmap *) 0 );
-  for( i = holep_vector.size() - 1; i >= 0 ; --i )
-    if( holep_vector[i] == p )
-      {
-      delete p;
-      holep_vector.erase( holep_vector.begin() + i );
-      return;
-      }
-  Ocrad::internal_error( "delete_hole, lost block." );
+
+  i = holep_vector.size();
+  while( --i >= 0 && holep_vector[i] != p );
+  if( i < 0 ) Ocrad::internal_error( "delete_hole, lost hole." );
+  holep_vector.erase( holep_vector.begin() + i );
+  delete p;
   }
 
 
-void join_holes( std::vector< Bitmap * > & holep_vector,
-                 std::vector< Bitmap * > & v1,
-                 std::vector< Bitmap * > & v2,
-                 Bitmap * p1, Bitmap * p2, int i ) throw()
+inline void join_holes( std::vector< Bitmap * > & holep_vector,
+                        std::vector< Bitmap * > & v1,
+                        std::vector< Bitmap * > & v2,
+                        Bitmap * p1, Bitmap * p2, int i ) throw()
   {
   if( p1->top() > p2->top() )
     {
@@ -231,18 +230,15 @@ bool Block::escape_bottom( int row, int col ) const throw()
 int Block::follow_top( int row, int col ) const throw()
   {
   if( !get_bit( row, col ) ) return row;
-  bool array[width()];
+  std::vector< char > array;
+  array.reserve( width() );
+  int c;
 
-  for( int c = col; c >= left(); --c )
-    {
-    if( get_bit( row, c ) ) array[c-left()] = true;
-    else { for( c -= left(); c >= 0; --c ) array[c] = false; break; }
-    }
-  for( int c = col + 1; c <= right(); ++c )
-    {
-    if( get_bit( row, c ) ) array[c-left()] = true;
-    else { for( c -= left(); c < width(); ++c ) array[c] = false; break; }
-    }
+  for( c = col; c > left() && get_bit( row, c - 1 ); --c );
+  if( c > left() ) array.resize( c - left(), false );
+  for( c = col; c < right() && get_bit( row, c + 1 ); ++c );
+  array.resize( c - left() + 1, true );
+  if( c < right() ) array.resize( width(), false );
 
   while( --row >= top() )
     {
@@ -266,18 +262,15 @@ int Block::follow_top( int row, int col ) const throw()
 int Block::follow_bottom( int row, int col ) const throw()
   {
   if( !get_bit( row, col ) ) return row;
-  bool array[width()];
+  std::vector< char > array;
+  array.reserve( width() );
+  int c;
 
-  for( int c = col; c >= left(); --c )
-    {
-    if( get_bit( row, c ) ) array[c-left()] = true;
-    else { for( c -= left(); c >= 0; --c ) array[c] = false; break; }
-    }
-  for( int c = col + 1; c <= right(); ++c )
-    {
-    if( get_bit( row, c ) ) array[c-left()] = true;
-    else { for( c -= left(); c < width(); ++c ) array[c] = false; break; }
-    }
+  for( c = col; c > left() && get_bit( row, c - 1 ); --c );
+  if( c > left() ) array.resize( c - left(), false );
+  for( c = col; c < right() && get_bit( row, c + 1 ); ++c );
+  array.resize( c - left() + 1, true );
+  if( c < right() ) array.resize( width(), false );
 
   while( ++row <= bottom() )
     {
@@ -447,7 +440,7 @@ void Block::find_holes() throw()
 
   for( int row = top(); row <= bottom(); ++row )
     {
-    std::swap( old_data, new_data );
+    old_data.swap( new_data );
     new_data[0] = get_bit( row, left() ) ? this : 0;
     for( int col = left() + 1; col < right(); ++col )
       {
@@ -455,31 +448,28 @@ void Block::find_holes() throw()
       if( get_bit( row, col ) ) new_data[dcol] = this;	// black point
       else						// white point
         {
-        Bitmap *tp = old_data[dcol];
+        Bitmap *p;
         Bitmap *lp = new_data[dcol-1];
+        Bitmap *tp = old_data[dcol];
         if( lp == 0 || tp == 0 )
           {
-          new_data[dcol] = 0;
+          p = 0;
           if( lp && lp != this )
             delete_hole( bpv, old_data, new_data, lp, dcol );
           else if( tp && tp != this )
             delete_hole( bpv, old_data, new_data, tp, dcol );
           }
-        else if( lp != this )
-          {
-          new_data[dcol] = lp; lp->add_point( row, col );
-          if( tp != this && tp != lp )
-            join_holes( bpv, old_data, new_data, lp, tp, dcol );
-          }
-        else if( tp != this )
-          { new_data[dcol] = tp; tp->add_point( row, col ); }
+        else if( lp != this ) { p = lp; p->add_point( row, col ); }
+        else if( tp != this ) { p = tp; p->add_point( row, col ); }
         else
           {
-          Bitmap *p = new Bitmap( col, row, col, row );
+          p = new Bitmap( col, row, col, row );
           p->set_bit( row, col, true );
           bpv.push_back( p );
-          new_data[dcol] = p;
           }
+        new_data[dcol] = p;
+        if( p && lp != tp && lp != this && tp != this )
+          join_holes( bpv, old_data, new_data, lp, tp, dcol );
         }
       }
     if( !get_bit( row, right() ) )
