@@ -16,8 +16,10 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
+#include <algorithm>
 #include <cstdio>
 #include <vector>
+
 #include "common.h"
 #include "rectangle.h"
 #include "ucs.h"
@@ -48,9 +50,9 @@ void Character::recognize13( const Charset & charset, const Rectangle & charbox
         { if( b2.width() >= 2 * b2.height() ) code = UCS::DIV; }
       else code = '%';
       }
-    else if( Ocrad::similar( b1.width(), b2.width(), 20 ) &&
-             Ocrad::similar( b1.height(), b2.height(), 20 ) &&
-             2 * b1.height() < b3.height() )
+    else if( 2 * std::max( b1.width(), b2.width() ) < b3.width() &&
+             Ocrad::similar( b1.height(), b2.height(), 20, 2 ) &&
+             2 * std::max( b1.height(), b2.height() ) < b3.height() )
       code = UCS::compose( c.guess( 0 ).code, ':' );
     else if( c.maybe('o') )
       {
