@@ -67,7 +67,7 @@ struct Control
 
   Control() throw()
     : format( byte ), outfile( stdout ), exportfile( 0 ),
-      debug_level( 0 ), filetype( 0 ), verbose( false )
-    {}
+      debug_level( 0 ), filetype( 0 ), verbose( false ) {}
+
   bool set_format( const char * name ) throw();
   };
