@@ -255,7 +255,10 @@ int Features::test_CEFIJLlT( const Charset & charset ) const throw()
             rp[rp.pos(60)] > rp[rp.pos(40)] + noise ) return 'z';
         return 'I';
         }
-      if( rp.isflats() && ( lp.istip() || lp.isflats() ) ) return 'l';
+      if( rp.isflats() &&
+          ( lp.istip() || lp.isflats() ||
+            ( lp.isctip() && lp.minima() == 2 && lp.iminimum(0) < lp.pos( 30 ) && lp.iminimum(1) > lp.pos( 80 ) ) ) )
+        return 'l';
       if( b.height() > 3 * wp.max() )
         {
         if( rp.istip() && lp.ispit() && Ocrad::similar( lp.iminimum(), rp.pos( 50 ), 10 ) )
@@ -264,7 +267,7 @@ int Features::test_CEFIJLlT( const Charset & charset ) const throw()
           { if( rp.istpit() ) return '}'; else return ')'; }
         if( rp.isflats() && 2 * vbar(0).size() >= b.area() ) return 'l';
         }
-      if( 2 * b.height() > 3 * b.width() )
+      if( 2 * b.height() > 3 * b.width() && lp.minima() <= 2 )
         if( rp.isflats() || rp.minima() == 1 )
           if( vbar(0).right() >= b.hpos( 70 ) ||
               b.escape_top( b.vpos( 75 ), std::min( b.right(), vbar(0).right() + 1 ) ) )
