@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004 Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,19 +13,20 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 class Textblock : public Rectangle
   {
-  mutable std::vector< Textline > data;
+  mutable std::vector< Textline * > tlpv;
 
 public:
   Textblock( const Rectangle & r, const Charset & charset,
-             const std::vector< std::vector< Block > > & block_matrix ) throw();
+             std::vector< std::vector< Block * > > & blockp_matrix ) throw();
+  ~Textblock() throw();
 
-  Textline & line( int i ) const throw();
-  int lines() const throw() { return data.size(); }
+//  Textline & textline( int i ) const throw();
+  int textlines() const throw() { return tlpv.size(); }
   int characters() const throw();
 
   void print( const Control & control ) const throw();
