@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004 Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,24 +13,21 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
-class Blockmap;
 class Textblock;
 
 class Textpage : public Rectangle
   {
   const std::string name;
-  const Blockmap * bmp;
   std::vector< Textblock * > tbpv;
 
 public:
-  Textpage( const Bitmap & page_image, const char * filename,
-            const Control & control ) throw();
+  Textpage( const Bitmap & page_image, const std::vector< Rectangle > & rv,
+            const char * filename, const Control & control ) throw();
   ~Textpage() throw();
 
-//  const Blockmap & blockmap() const throw() { return *bmp; }
 //  const Textblock & textblock( int i ) const throw();
   int textblocks() const throw() { return tbpv.size(); }
 
