@@ -18,14 +18,19 @@
 
 #include <algorithm>
 #include <vector>
+
 #include "common.h"
 #include "rectangle.h"
-#include "vrhomboid.h"
 #include "track.h"
 
 
 namespace {
 
+void error( const char * s ) throw() __attribute__ ((noreturn));
+void error( const char * s ) throw()
+  { Ocrad::internal_error( s ); }
+
+
 int good_reference( const Rectangle & r1, const Rectangle & r2, int & val,
                     int mean_height, int mean_width ) throw()
   {
@@ -86,6 +91,82 @@ int set_r( const std::vector< Rectangle > & rectangle_vector,
 } // end namespace
 
 
+Vrhomboid::Vrhomboid( int l, int lc, int r, int rc, int h ) throw()
+  {
+  if( r < l || h <= 0 )
+    {
+    std::fprintf( stderr, "l = %d, lc = %d, r = %d, rc = %d, h = %d\n",
+                  l, lc, r, rc, h );
+    error( "bad parameter building a Vrhomboid" );
+    }
+  _left = l; _lvcenter = lc; _right = r; _rvcenter = rc; _height = h;
+  }
+
+
+void Vrhomboid::left( int l ) throw()
+  {
+  if( l > _right ) error( "left, bad parameter resizing a Vrhomboid" );
+  _left = l;
+  }
+
+
+void Vrhomboid::right( int r ) throw()
+  {
+  if( r < _left ) error( "right, bad parameter resizing a Vrhomboid" );
+  _right = r;
+  }
+
+
+void Vrhomboid::height( int h ) throw()
+  {
+  if( h <= 0 ) error( "height, bad parameter resizing a Vrhomboid" );
+  _height = h;
+  }
+
+
+void Vrhomboid::extend_left( int l ) throw()
+  {
+  if( l > _right )
+    error( "extend_left, bad parameter resizing a Vrhomboid" );
+  _lvcenter = vcenter( l ); _left = l;
+  }
+
+
+void Vrhomboid::extend_right( int r ) throw()
+  {
+  if( r < _left )
+    error( "extend_right, bad parameter resizing a Vrhomboid" );
+  _rvcenter = vcenter( r ); _right = r;
+  }
+
+
+int Vrhomboid::vcenter( int col ) const throw()
+  {
+  int dx = _right - _left, dy = _rvcenter - _lvcenter;
+  int vc = _lvcenter;
+  if( dx && dy ) vc += ( dy * ( col - _left ) ) / dx;
+  return vc;
+  }
+
+
+bool Vrhomboid::includes( const Rectangle & r ) const throw()
+  {
+  if( r.left() < _left || r.right() > _right ) return false;
+  int tl = top( r.left() ), bl = tl +_height - 1;
+  int tr = top( r.right() ), br = tr +_height - 1;
+  int t = std::max( tl, tr ), b = std::min( bl, br );
+  return ( t <= r.top() && b >= r.bottom() );
+  }
+
+
+bool Vrhomboid::includes( int row, int col ) const throw()
+  {
+  if( col < _left || col > _right ) return false;
+  int t = top( col ), b = t +_height - 1;
+  return ( t <= row && b >= row );
+  }
+
+
 // rectangle_vector must be ordered by increasing hcenter().
 //
 void Track::set_track( const std::vector< Rectangle > & rectangle_vector ) throw()
