@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004 Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 #include <cctype>
@@ -144,6 +144,8 @@ int UCS::compose( int letter, int accent ) throw()
               if( accent == '`' ) return SUGRAVE;
               if( accent == '^' ) return SUCIRCU;
               if( accent == ':' ) return SUDIAER; break;
+    case 'y': if( accent == '\'') return SYACUTE;
+              if( accent == ':' ) return SYDIAER; break;
     case 'z': return SZCARON;
     }
   return 0;
@@ -261,30 +263,6 @@ char * UCS::ucs_to_utf8( int code ) throw()
   return s;
   }
 
-/*
-int utf8_to_ucs( const char * s ) throw()
-  {
-  unsigned char first = s[0];
-  if( first < 128 ) return first;			// plain ascii
-  if( first < 192 || first > 253 ) return -1;		// invalid byte
-
-  int c = 2;
-  unsigned char bit = 0x20, mask = 0x1F;
-  while( first & bit ) { ++c; bit >>= 1; mask >>= 1; }
-  int code = first & mask;
-
-  for( int i = 1; i < c; ++i )
-    {
-    unsigned char next = s[i];
-    if( ( next & 0xC0 ) != 0x80 ) return -1;		// invalid byte
-    code = ( code << 6 ) | ( next & 0x3F );
-    }
-
-  if( code < 0x80 || ( c > 2 && code < 0x800 << ( ( c - 3 ) * 5 ) ) )
-    return -1;						// no minimum length
-  return code;
-  }
-*/
 
 int UCS::toupper( int code ) throw()
   {
